#!/usr/bin/perl
use strict;

package MATT::Apache;

use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);

$VERSION  = '0.1.0';

use Exporter;
use MATT::Utility;
use MATT::FreeBSD;

@ISA = qw(Exporter);
@EXPORT = qw(
	InstallApache1
	InstallApache2
);
@EXPORT_OK = qw( RemoveOldApacheSources );



sub InstallApache2
{
	print "\n";
	InstallPackage("p5-libwww");
	InstallPackage("apache2", "apache-2");
	InstallPort   ("perl5",       "lang", "", "perl-5");
	SysCmd("/usr/local/bin/use.perl port");
	InstallPort   ("cronolog", "sysutils");
	InstallPort   ("mod_php4", "www");
	InstallPort   ("mod_perl2", "www");
};

sub InstallApache1($;$) 
{
	my ($src) = @_;

	my $apache   = "apache_1.3.27";
	my $mod_perl = "mod_perl-1.27";
	my $mod_ssl  = "mod_ssl-2.8.14-1.3.27";
	my $layout   = "FreeBSD.layout";

	InstallPackage("mm");
	InstallPackage("gettext");
	InstallPackage("libtool");
	InstallPackage("apache");
	InstallPackage("p5-libwww");
	InstallPort   ("cronolog", "sysutils");

	my $log = "/var/log/apache";
	if (! -d $log) 
	{
		mkdir($log, 0755) or die "Couldn't create $log: $!\n";
		my $uid = getpwnam("www");
		my $gid = getgrnam("www");
		chown($uid, $gid, $log);
	};

	CdSrcDir("$src/www");

	if ( !-e "$apache.tar.gz" ) {
		FetchFile("http://www.apache.org/dist/httpd/$apache.tar.gz");
	};

	if ( !-e "$mod_perl.tar.gz" ) {
		FetchFile("http://perl.apache.org/dist/$mod_perl.tar.gz");
	};

	if ( !-e "$mod_ssl.tar.gz" ) {
		FetchFile("http://www.modssl.org/source/$mod_ssl.tar.gz");
	};

	if ( !-e $layout ) 
	{
		FetchFile("http://matt.simerson.net/computing/www/apache.layout");
		move("apache.layout", $layout);
	};

	RemoveOldApacheSources($apache);

	foreach my $package ( $apache, $mod_perl, $mod_ssl) 
	{
		if ( -d $package )
		{
			my $r = SourceWarning($package, 1);
			if (! $r) { die "sorry, I can't continue.\n"; };
		};
		my $tar = FindTheBin("tar");
		SysCmd("$tar -xzf $package.tar.gz");
	};

	chdir($mod_ssl);
	SysCmd("./configure --with-apache=../$apache --with-ssl=/usr --enable-shared=ssl --with-mm=/usr/local");
	chdir("../$mod_perl");
	SysCmd( "perl Makefile.PL DO_HTTPD=1 USE_APACI=1 APACHE_PREFIX=/usr/local EVERYTHING=1 APACI_ARGS='--server-uid=www, --server-gid=www, --enable-module=so --enable-module=most, --enable-shared=max --disable-shared=perl, --enable-module=perl, --with-layout=../$layout:FreeBSD, --without-confadjust'");
	SysCmd("make");

	if (-e "../$apache/src/httpd") 
	{
		print <<EOM

Apache build successful, now you must install as follows:

For new installs:

     cd $src/www/$mod_perl
     make test
     cd ../$apache; make certificate TYPE=custom
     rm /usr/local/etc/apache/httpd.conf
     cd ../$mod_perl; make install
     cd /usr/ports/www/mod_php4; make install clean (optional)
     apachectl stop; apachectl startssl

For re-installs:

     cd $src/www/$mod_perl;\n\tmake test
     make install
     cd /usr/ports/www/mod_php4; make install clean (optional)
     apachectl stop; apachectl startssl
EOM
;
	};
};

sub RemoveOldApacheSources
{
	my ($apache) = @_;

	my @list = <apache_1.*>;
	foreach my $dir (@list)
	{
		if ( $dir ne $apache && $dir !~ /\.tar\.gz$/ )
		{
			print "deleting: $dir... ";
			rmtree $_ or die "couldn't delete $_: $!\n";    
			print "done.";
		};       
	};
};

1;
__END__
